summaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorAndreas Fischer <bantu@owncloud.com>2014-03-16 19:54:05 +0100
committerAndreas Fischer <bantu@owncloud.com>2014-05-29 16:26:02 +0200
commitea246d058ed86acc6634d34888d61f2a953e6ce1 (patch)
tree4af80dfd9a0e2cf886b016189709c5a7c28e45b6 /tests
parent0417e52134e87c379b3b4c22a53a0c06a711baef (diff)
downloadnextcloud-server-ea246d058ed86acc6634d34888d61f2a953e6ce1.tar.gz
nextcloud-server-ea246d058ed86acc6634d34888d61f2a953e6ce1.zip
Use "file size" instead of "filesize", then also apply camel case.
Diffstat (limited to 'tests')
-rw-r--r--tests/lib/largefilehelpergetfilesize.php32
1 files changed, 16 insertions, 16 deletions
diff --git a/tests/lib/largefilehelpergetfilesize.php b/tests/lib/largefilehelpergetfilesize.php
index 699dd6891ad..cc25d54a36a 100644
--- a/tests/lib/largefilehelpergetfilesize.php
+++ b/tests/lib/largefilehelpergetfilesize.php
@@ -9,61 +9,61 @@
namespace Test;
/**
* Tests whether LargeFileHelper is able to determine filesize at all.
* Large files are not considered yet.
*/
-class LargeFileHelperGetFilesize extends \PHPUnit_Framework_TestCase {
+class LargeFileHelperGetFileSize extends \PHPUnit_Framework_TestCase {
protected $filename;
- protected $filesize;
+ protected $fileSize;
protected $helper;
public function setUp() {
parent::setUp();
$this->filename = __DIR__ . '/../data/data.tar.gz';
- $this->filesize = 4195;
+ $this->fileSize = 4195;
$this->helper = new \OC\LargeFileHelper;
}
- public function testGetFilesizeViaCurl() {
+ public function testGetFileSizeViaCurl() {
if (!extension_loaded('curl')) {
$this->markTestSkipped(
'The PHP curl extension is required for this test.'
);
}
$this->assertSame(
- $this->filesize,
- $this->helper->getFilesizeViaCurl($this->filename)
+ $this->fileSize,
+ $this->helper->getFileSizeViaCurl($this->filename)
);
}
- public function testGetFilesizeViaCOM() {
+ public function testGetFileSizeViaCOM() {
if (!extension_loaded('COM')) {
$this->markTestSkipped(
'The PHP Windows COM extension is required for this test.'
);
}
$this->assertSame(
- $this->filesize,
- $this->helper->getFilesizeViaDOM($this->filename)
+ $this->fileSize,
+ $this->helper->getFileSizeViaDOM($this->filename)
);
}
- public function testGetFilesizeViaExec() {
+ public function testGetFileSizeViaExec() {
if (!\OC_Helper::is_function_enabled('exec')) {
$this->markTestSkipped(
'The exec() function needs to be enabled for this test.'
);
}
$this->assertSame(
- $this->filesize,
- $this->helper->getFilesizeViaExec($this->filename)
+ $this->fileSize,
+ $this->helper->getFileSizeViaExec($this->filename)
);
}
- public function testGetFilesizeNative() {
+ public function testGetFileSizeNative() {
$this->assertSame(
- $this->filesize,
- $this->helper->getFilesizeNative($this->filename)
+ $this->fileSize,
+ $this->helper->getFileSizeNative($this->filename)
);
}
}
@@ -9,61 +9,61 @@
namespace Test;
/**
-* Tests whether LargeFileHelper is able to determine filesize at all.
+* Tests whether LargeFileHelper is able to determine file size at all.
* Large files are not considered yet.
*/